@@ -5,6 +5,6 @@ test.file <- function(...) {
 release_bullets <- function() {
   c(
     '`rhub::check(platform = "debian-gcc-devel-nold")`',
-    '`rhub::check_on_solaris()`'
+    NULL
   )
 }
